@@ -40,12 +40,22 @@ void DBusService::addUrls(const QStringList &urls) {
     UrlChecker::instance()->addUrlsToQueue(urls);
 }
 
+void DBusService::addUrls(const QStringList &urls, const QString &service) {
+    UrlChecker::instance()->addUrlsToQueue(urls, service);
+}
+
 void DBusService::importUrls(const QStringList &urls) {
     foreach (QString url, urls) {
         UrlChecker::instance()->importUrlsFromTextFile(url);
     }
 }
 
+void DBusService::importUrls(const QStringList &urls, const QString &service) {
+    foreach (QString url, urls) {
+        UrlChecker::instance()->importUrlsFromTextFile(url, service);
+    }
+}
+
 void DBusService::retrieveUrls(const QStringList &urls) {
     UrlRetriever::instance()->addUrlsToQueue(urls);
 }
