@@ -292,13 +292,12 @@ MainWindow::MainWindow(QWidget *parent) :
     this->connect(Settings::instance(), SIGNAL(downloadRateLimitChanged(int)), this, SLOT(onDownloadRateLimitChanged(int)));
     this->connect(Database::instance(), SIGNAL(categoriesChanged()), this, SLOT(setCategoryMenuActions()));
     this->connect(ClipboardMonitor::instance(), SIGNAL(clipboardUrlsReady(QString)), this, SLOT(showAddUrlsDialog(QString)));
-    this->connect(PluginManager::instance(), SIGNAL(busy(QString,int)), this, SLOT(showProgressDialog(QString,int)));
-    this->connect(PluginManager::instance(), SIGNAL(progressChanged(int)), this, SLOT(updateProgressDialog(int)));
     this->connect(PluginManager::instance(), SIGNAL(pluginsReady()), this, SLOT(onPluginsReady()));
-    this->connect(PluginManager::instance(), SIGNAL(pluginsReady()), this, SLOT(hideProgressDialog()));
 
     this->onPackageCountChanged(m_model->rowCount());
     this->setCategoryMenuActions();
+    
+    PluginManager::instance()->loadPlugins();
 }
 
 MainWindow::~MainWindow() {}
@@ -349,14 +348,6 @@ void MainWindow::keyPressEvent(QKeyEvent *event) {
     QMainWindow::keyPressEvent(event);
 }
 
-void MainWindow::showEvent(QShowEvent *event) {
-    if (PluginManager::instance()->servicePlugins().isEmpty()) {
-        QTimer::singleShot(1000, PluginManager::instance(), SLOT(loadPlugins()));
-    }
-
-    QMainWindow::showEvent(event);
-}
-
 void MainWindow::setFullScreen(bool fullScreen) {
     if (fullScreen) {
         this->showFullScreen();
@@ -631,7 +622,7 @@ void MainWindow::pauseCurrentTransfer() {
 
 void MainWindow::removeCurrentTransfer() {
     if (m_view->currentIndex().isValid()) {
-        m_model->setData(m_filterModel->mapToSource(m_view->currentIndex()), Transfers::Cancelled, Transfer::StatusRole);
+        m_model->setData(m_filterModel->mapToSource(m_view->currentIndex()), Transfers::Canceled, Transfer::StatusRole);
     }
 }
 
@@ -710,7 +701,7 @@ void MainWindow::removeCurrentPackage() {
         m_model->setData(m_filterModel->mapToSource(m_view->currentIndex().parent().isValid()
                                                     ? m_view->currentIndex().parent()
                                                     : m_view->currentIndex()),
-                                                    Transfers::Cancelled, Transfer::PackageStatusRole);
+                                                    Transfers::Canceled, Transfer::PackageStatusRole);
     }
 }
 
@@ -791,7 +782,7 @@ void MainWindow::retrieveUrlsFromText(const QString &text) {
     this->connect(UrlRetriever::instance(), SIGNAL(progressChanged(int)), this, SLOT(updateProgressDialog(int)));
     this->connect(UrlRetriever::instance(), SIGNAL(finished()), this, SLOT(onUrlRetrieverFinished()));
     this->connect(UrlRetriever::instance(), SIGNAL(finished()), this, SLOT(hideProgressDialog()));
-    this->connect(UrlRetriever::instance(), SIGNAL(cancelled()), this, SLOT(hideProgressDialog()));
+    this->connect(UrlRetriever::instance(), SIGNAL(canceled()), this, SLOT(hideProgressDialog()));
     UrlRetriever::instance()->parseUrlsFromText(text);
 }
 
