@@ -1,5 +1,21 @@
+/*
+ * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU Lesser General Public License,
+ * version 3, as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
+ * more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
+ */
+
 #include "retrieveurlsdialog.h"
-#include "../shared/urlretriever.h"
 #include "../shared/settings.h"
 #include "../shared/database.h"
 #include <QTextEdit>
@@ -7,6 +23,7 @@
 #include <QPushButton>
 #include <QHBoxLayout>
 #include <QFile>
+#include <QUrl>
 
 RetrieveUrlsDialog::RetrieveUrlsDialog(QWidget *parent) :
     QDialog(parent),
@@ -20,7 +37,8 @@ RetrieveUrlsDialog::RetrieveUrlsDialog(QWidget *parent) :
     hbox->addWidget(m_urlsEdit);
     hbox->addWidget(m_buttonBox);
 
-    this->connect(m_buttonBox, SIGNAL(accepted()), this, SLOT(parseUrls()));
+    this->connect(m_buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
+    this->connect(m_urlsEdit, SIGNAL(textChanged()), this, SLOT(onTextChanged()));
 }
 
 RetrieveUrlsDialog::~RetrieveUrlsDialog() {}
@@ -49,11 +67,11 @@ void RetrieveUrlsDialog::parseUrlsFromTextFile(const QString &fileName) {
     }
 }
 
-void RetrieveUrlsDialog::onTextChanged() {
-    m_buttonBox->button(QDialogButtonBox::Ok)->setEnabled(!m_urlsEdit->toPlainText().isEmpty());
+void RetrieveUrlsDialog::accept() {
+    emit urlsAvailable(this->text());
+    QDialog::accept();
 }
 
-void RetrieveUrlsDialog::parseUrls() {
-    UrlRetriever::instance()->parseUrlsFromText(m_urlsEdit->toPlainText());
-    this->accept();
+void RetrieveUrlsDialog::onTextChanged() {
+    m_buttonBox->button(QDialogButtonBox::Ok)->setEnabled(!this->text().isEmpty());
 }
