@@ -67,8 +67,8 @@ Transfer::Transfer(QObject *parent) :
     m_checkedIfConvertible(false),
     m_convert(false),
     m_row(0),
-    m_preferredConnections(1),
-    m_maxConnections(1)
+    m_preferredConnections(qMin(Settings::instance()->maximumConnectionsPerTransfer(), MAX_CONNECTIONS)),
+    m_maxConnections(MAX_CONNECTIONS)
   #ifdef QML_USER_INTERFACE
     ,m_expanded(false)
   #endif
@@ -212,7 +212,7 @@ bool Transfer::setData(int role, const QVariant &value) {
         case Transfers::Paused:
             this->pause();
             break;
-        case Transfers::Cancelled:
+        case Transfers::Canceled:
             this->cancel();
             break;
         }
@@ -234,7 +234,7 @@ bool Transfer::setData(int role, const QVariant &value) {
         case Transfers::Paused:
             this->pausePackage();
             break;
-        case Transfers::Cancelled:
+        case Transfers::Canceled:
             this->cancelPackage();
             break;
         }
@@ -444,22 +444,10 @@ void Transfer::setServiceName(const QString &name) {
 
         if (name.isEmpty()) {
             this->setIconFileName(ICON_PATH + "qdl.png");
-            this->setPreferredConnections(1);
-            this->setMaximumConnections(1);
         }
         else {
             ServicePlugin *plugin = PluginManager::instance()->getServicePlugin(name);
             this->setIconFileName(ICON_PATH + (!plugin ? "qdl.png" : plugin->iconName()));
-
-            if ((plugin) && (plugin->maximumConnections() <= 0)) {
-                // Plugin allows unlimited connections
-                this->setMaximumConnections(MAX_CONNECTIONS);
-                this->setPreferredConnections(Settings::instance()->maximumConnectionsPerTransfer(), false);
-            }
-            else {
-                this->setMaximumConnections(!plugin ? 1 : qMin(plugin->maximumConnections(), MAX_CONNECTIONS));
-                this->setPreferredConnections(!plugin ? 1 : qMin(plugin->maximumConnections(), Settings::instance()->maximumConnectionsPerTransfer()), false);
-            }
         }
     }
 }
@@ -603,7 +591,7 @@ void Transfer::setStatus(Transfers::Status status) {
         case Transfers::CaptchaRequired:
             m_captchaTime.start();
             break;
-        case Transfers::Cancelled:
+        case Transfers::Canceled:
             this->removeFiles();
 
             if (m_servicePlugin) m_servicePlugin->cancelCurrentOperation();
@@ -683,21 +671,14 @@ int Transfer::preferredConnections() const {
     return m_preferredConnections;
 }
 
-void Transfer::setPreferredConnections(int pref, bool overrideGlobalSetting) {
-    if ((pref != this->preferredConnections()) && (pref > 0) && (pref < this->maximumConnections())) {
+void Transfer::setPreferredConnections(int pref) {
+    if ((pref != this->preferredConnections()) && (pref > 0) && (pref <= this->maximumConnections())) {
         m_preferredConnections = pref;
 #ifdef QML_USER_INTERFACE
         emit preferredConnectionsChanged();
 #else
         emit dataChanged(PreferredConnectionsRole);
 #endif
-        if (overrideGlobalSetting) {
-            this->disconnect(Settings::instance(), SIGNAL(maximumConnectionsPerTransferChanged(int,int)), this, SLOT(onMaximumConnectionsChanged(int,int)));
-        }
-        else {
-            this->connect(Settings::instance(), SIGNAL(maximumConnectionsPerTransferChanged(int,int)), this, SLOT(onMaximumConnectionsChanged(int,int)));
-        }
-
         if (this->status() == Transfers::Downloading) {
             if (pref > this->activeConnections()) {
                 this->addConnections(pref - this->activeConnections());
@@ -996,9 +977,32 @@ void Transfer::start() {
         m_servicePlugin->setNetworkAccessManager(m_nam);
 
         this->connect(m_servicePlugin, SIGNAL(waiting(int)), this, SLOT(onServicePluginWaiting(int)));
-        this->connect(m_servicePlugin, SIGNAL(statusChanged(ServicePlugin::Status)), this, SLOT(onServicePluginStatusChanged(ServicePlugin::Status)));
-        this->connect(m_servicePlugin, SIGNAL(error(ServicePlugin::ErrorType)), this, SLOT(onServicePluginError(ServicePlugin::ErrorType)));
-        this->connect(m_servicePlugin, SIGNAL(downloadRequestReady(QNetworkRequest,QByteArray)), this, SLOT(onDownloadRequestReady(QNetworkRequest,QByteArray)));
+        this->connect(m_servicePlugin, SIGNAL(statusChanged(ServicePlugin::Status)),
+                      this, SLOT(onServicePluginStatusChanged(ServicePlugin::Status)));
+        this->connect(m_servicePlugin, SIGNAL(error(ServicePlugin::ErrorType)),
+                      this, SLOT(onServicePluginError(ServicePlugin::ErrorType)));
+        this->connect(m_servicePlugin, SIGNAL(downloadRequestReady(QNetworkRequest,QByteArray)),
+                      this, SLOT(onDownloadRequestReady(QNetworkRequest,QByteArray)));
+                      
+        if (m_servicePlugin->loginSupported()) {
+            this->connect(m_servicePlugin, SIGNAL(loggedIn(bool)), this, SLOT(onServicePluginLoggedIn(bool)));
+        }
+    }
+    
+    if (m_servicePlugin->loginSupported()) {
+        QPair<QString, QString> account = Database::instance()->getAccount(m_servicePlugin->serviceName());
+        
+        if ((!account.first.isEmpty()) && (!account.second.isEmpty())) {
+            qDebug() << "Logging in:" << m_servicePlugin->serviceName();
+            this->setStatus(Transfers::Connecting);
+            m_servicePlugin->login(account.first, account.second);
+            return;
+        }
+    }
+    
+    if (m_servicePlugin->maximumConnections() > 0) {
+        this->setMaximumConnections(qMin(m_servicePlugin->maximumConnections(), MAX_CONNECTIONS));
+        this->setPreferredConnections(qMin(m_servicePlugin->maximumConnections(), this->preferredConnections()));
     }
 
     m_servicePlugin->getDownloadRequest(this->url());
@@ -1034,11 +1038,24 @@ void Transfer::cancel() {
 
         return;
     default:
-        this->setStatus(Transfers::Cancelled);
+        this->setStatus(Transfers::Canceled);
         return;
     }
 }
 
+void Transfer::onServicePluginLoggedIn(bool ok) {
+    qDebug() << (ok ? "Login successful:" : "Login failed:")  << this->serviceName();
+    
+    if (m_servicePlugin) {
+        if (m_servicePlugin->maximumConnections() > 0) {
+            this->setMaximumConnections(qMin(m_servicePlugin->maximumConnections(), MAX_CONNECTIONS));
+            this->setPreferredConnections(qMin(m_servicePlugin->maximumConnections(), this->preferredConnections()));
+        }
+        
+        m_servicePlugin->getDownloadRequest(this->url());
+    }
+}
+
 void Transfer::onServicePluginWaiting(int msecs) {
     this->setStatusInfo(Utils::durationFromMSecs(msecs));
 }
@@ -1100,7 +1117,8 @@ void Transfer::onServicePluginError(ServicePlugin::ErrorType errorType) {
         this->setStatusInfo(tr("Network error"));
         break;
     default:
-        this->setStatusInfo(m_servicePlugin->errorString().isEmpty() ? tr("Cannot retreive download url") : m_servicePlugin->errorString());
+        this->setStatusInfo(m_servicePlugin->errorString().isEmpty() ? tr("Cannot retreive download url")
+                                                                     : m_servicePlugin->errorString());
     }
 
     this->setStatus(Transfers::Failed);
@@ -1125,8 +1143,10 @@ void Transfer::onCaptchaRequired() {
         m_recaptchaPlugin->setParent(this);
         m_recaptchaPlugin->setNetworkAccessManager(m_nam);
 
-        this->connect(m_recaptchaPlugin, SIGNAL(error(RecaptchaPlugin::ErrorType)), this, SLOT(onRecaptchaPluginError(RecaptchaPlugin::ErrorType)));
-        this->connect(m_recaptchaPlugin, SIGNAL(captchaReady(QByteArray)), this, SLOT(onCaptchaReady(QByteArray)));
+        this->connect(m_recaptchaPlugin, SIGNAL(error(RecaptchaPlugin::ErrorType)),
+                      this, SLOT(onRecaptchaPluginError(RecaptchaPlugin::ErrorType)));
+        this->connect(m_recaptchaPlugin, SIGNAL(captchaReady(QByteArray)),
+                      this, SLOT(onCaptchaReady(QByteArray)));
     }
     else if (m_recaptchaPlugin->serviceName() != m_servicePlugin->recaptchaServiceName()) {
         delete m_recaptchaPlugin;
@@ -1141,10 +1161,12 @@ void Transfer::onCaptchaRequired() {
         m_recaptchaPlugin->setParent(this);
         m_recaptchaPlugin->setNetworkAccessManager(m_nam);
 
-        this->connect(m_recaptchaPlugin, SIGNAL(error(RecaptchaPlugin::ErrorType)), this, SLOT(onRecaptchaPluginError(RecaptchaPlugin::ErrorType)));
-        this->connect(m_recaptchaPlugin, SIGNAL(captchaReady(QByteArray)), this, SLOT(onCaptchaReady(QByteArray)));
+        this->connect(m_recaptchaPlugin, SIGNAL(error(RecaptchaPlugin::ErrorType)),
+                      this, SLOT(onRecaptchaPluginError(RecaptchaPlugin::ErrorType)));
+        this->connect(m_recaptchaPlugin, SIGNAL(captchaReady(QByteArray)),
+                      this, SLOT(onCaptchaReady(QByteArray)));
     }
-
+    
     this->setStatusInfo(tr("Retrieving captcha challenge"));
 
     m_recaptchaPlugin->getCaptcha(m_servicePlugin->recaptchaKey());
@@ -1185,8 +1207,10 @@ void Transfer::onCaptchaReady(const QByteArray &imageData) {
             m_decaptchaPlugin->setParent(this);
             m_decaptchaPlugin->setNetworkAccessManager(m_nam);
 
-            this->connect(m_decaptchaPlugin, SIGNAL(error(DecaptchaPlugin::ErrorType)), this, SLOT(onDecaptchaPluginError(DecaptchaPlugin::ErrorType)));
-            this->connect(m_decaptchaPlugin, SIGNAL(captchaResponseReady(QString)), this, SLOT(onCaptchaResponseReady(QString)));
+            this->connect(m_decaptchaPlugin, SIGNAL(error(DecaptchaPlugin::ErrorType)),
+                          this, SLOT(onDecaptchaPluginError(DecaptchaPlugin::ErrorType)));
+            this->connect(m_decaptchaPlugin, SIGNAL(captchaResponseReady(QString)),
+                          this, SLOT(onCaptchaResponseReady(QString)));
         }
         else if (Settings::instance()->decaptchaService() != m_decaptchaPlugin->serviceName()) {
             delete m_decaptchaPlugin;
@@ -1201,8 +1225,16 @@ void Transfer::onCaptchaReady(const QByteArray &imageData) {
             m_decaptchaPlugin->setParent(this);
             m_decaptchaPlugin->setNetworkAccessManager(m_nam);
 
-            this->connect(m_decaptchaPlugin, SIGNAL(error(DecaptchaPlugin::ErrorType)), this, SLOT(onDecaptchaPluginError(DecaptchaPlugin::ErrorType)));
-            this->connect(m_decaptchaPlugin, SIGNAL(captchaResponseReady(QString)), this, SLOT(onCaptchaResponseReady(QString)));
+            this->connect(m_decaptchaPlugin, SIGNAL(error(DecaptchaPlugin::ErrorType)),
+                          this, SLOT(onDecaptchaPluginError(DecaptchaPlugin::ErrorType)));
+            this->connect(m_decaptchaPlugin, SIGNAL(captchaResponseReady(QString)),
+                          this, SLOT(onCaptchaResponseReady(QString)));
+        }
+        
+        QPair<QString, QString> account = Database::instance()->getAccount(m_decaptchaPlugin->serviceName());
+
+        if ((!account.first.isEmpty()) && (!account.second.isEmpty())) {
+            m_decaptchaPlugin->login(account.first, account.second);
         }
 
         this->setStatusInfo(QString("%1 %2").arg(tr("Retrieving captcha response from")).arg(m_decaptchaPlugin->serviceName()));
@@ -1405,7 +1437,7 @@ void Transfer::onConnectionStatusChanged(Transfers::Status status) {
         }
 
         break;
-    case Transfers::Cancelled:
+    case Transfers::Canceled:
         foreach (Connection *connection, m_connections) {
             if (connection->status() != status) {
                 return;
@@ -1436,7 +1468,8 @@ void Transfer::onConnectionCompleted(Connection *connection) {
                 this->onFileWriteCompleted();
             }
         }
-        else if ((this->activeConnections() < this->preferredConnections()) && ((this->size() - this->position()) > MIN_FRAGMENT_SIZE)) {
+        else if ((this->activeConnections() < this->preferredConnections())
+                  && ((this->size() - this->position()) > MIN_FRAGMENT_SIZE)) {
             this->addConnections();
         }
     }
@@ -1504,7 +1537,8 @@ void Transfer::extractArchive(const QString &password) {
         outputDirectory = Settings::instance()->downloadPath();
     }
 
-    m_extractor->start(this->downloadPath() + this->fileName(), outputDirectory, password, Settings::instance()->createSubfolderForArchives());
+    m_extractor->start(this->downloadPath() + this->fileName(), outputDirectory, password,
+                       Settings::instance()->createSubfolderForArchives());
 }
 
 void Transfer::onArchiveExtractionFinished() {
@@ -1564,8 +1598,10 @@ void Transfer::moveFiles() {
         int i = 1;
 
         while ((destinationDir.exists(fileName)) && (i < 100)) {
-            fileName = (i == 1 ? QString("%1(%2)%3").arg(fileName.left(fileName.lastIndexOf('.'))).arg(i).arg(fileName.mid(fileName.lastIndexOf('.')))
-                              : QString("%1(%2)%3").arg(fileName.left(fileName.lastIndexOf('('))).arg(i).arg(fileName.mid(fileName.lastIndexOf('.'))));
+            fileName = (i == 1 ? QString("%1(%2)%3").arg(fileName.left(fileName.lastIndexOf('.')))
+                                                    .arg(i).arg(fileName.mid(fileName.lastIndexOf('.')))
+                              : QString("%1(%2)%3").arg(fileName.left(fileName.lastIndexOf('('))).arg(i)
+                                                   .arg(fileName.mid(fileName.lastIndexOf('.'))));
             i++;
         }
 
@@ -1593,7 +1629,8 @@ void Transfer::removeFiles() {
     this->removeCaptchaFile();
 
     if (!m_file.remove()) {
-        QFile::remove(QString("%1%2%3").arg(this->downloadPath()).arg(this->downloadPath().endsWith("/") ? "" : "/").arg(this->fileName()));
+        QFile::remove(QString("%1%2%3").arg(this->downloadPath()).arg(this->downloadPath().endsWith("/") ? "" : "/")
+                                       .arg(this->fileName()));
     }
 
     if ((m_transfers.isEmpty()) && (this->isPackage())) {
