@@ -257,7 +257,7 @@ public:
     void setConvertToAudio(bool convert);
 
     int preferredConnections() const;
-    void setPreferredConnections(int pref, bool overrideGlobalSetting = true);
+    void setPreferredConnections(int pref);
 
     int maximumConnections() const;
 
@@ -316,6 +316,7 @@ private slots:
     void onCaptchaReady(const QByteArray &imageData);
     void onDecaptchaPluginError(DecaptchaPlugin::ErrorType errorType);
     void onCaptchaResponseReady(const QString &response);
+    void onServicePluginLoggedIn(bool ok);
     void onServicePluginWaiting(int msecs);
     void onServicePluginStatusChanged(ServicePlugin::Status status);
     void onServicePluginError(ServicePlugin::ErrorType errorType);
