@@ -225,6 +225,10 @@ QModelIndex TransferModel::index(int row, int column, const QModelIndex &parent)
     return QModelIndex();
 }
 
+QVariant TransferModel::modelIndex(int row, int column, const QModelIndex &parent) const {
+    return QVariant::fromValue(this->index(row, column, parent));
+}
+
 QModelIndex TransferModel::parent(const QModelIndex &child) const {
     if (!child.isValid()) {
         return QModelIndex();
@@ -245,6 +249,10 @@ QModelIndex TransferModel::parent(const QModelIndex &child) const {
     return this->createIndex(parentTransfer->rowNumber(), 0, parentTransfer);
 }
 
+QVariant TransferModel::parentModelIndex(const QModelIndex &child) const {
+    return QVariant::fromValue(this->parent(child));
+}
+
 #ifdef TABLE_TRANSFER_VIEW
 QVariant TransferModel::headerData(int section, Qt::Orientation orientation, int role) const {
     if ((orientation != Qt::Horizontal) || (role != Qt::DisplayRole)) {
@@ -314,9 +322,8 @@ QVariant TransferModel::data(const QModelIndex &index, int role) const {
     return QVariant();
 }
 
-QVariant TransferModel::data(int row, int parentRow, const QByteArray &role) const {
-    return this->data(this->index(row, 0, parentRow >= 0 ? this->index(parentRow, 0)
-                                                         : QModelIndex()), this->roleNames().key(role));
+QVariant TransferModel::data(const QModelIndex &index, const QByteArray &role) const {
+    return this->data(index, this->roleNames().key(role));
 }
 
 QVariant TransferModel::data(const QString &id, const QByteArray &role) const {
@@ -337,14 +344,6 @@ QMap<int, QVariant> TransferModel::itemData(const QModelIndex &index) const {
     return QMap<int, QVariant>();
 }
 
-QVariantMap TransferModel::itemData(int row, int parentRow) const {
-    if (Transfer *transfer = this->get(row, parentRow)) {
-        return transfer->itemDataWithRoleNames();
-    }
-
-    return QVariantMap();
-}
-
 QVariantMap TransferModel::itemData(const QString &id) const {
     foreach (Transfer *transfer, m_rootItem->childTransfers()) {
         if (transfer->id() == id) {
@@ -466,9 +465,8 @@ bool TransferModel::setData(const QModelIndex &index, const QVariant &value, int
     return false;
 }
 
-bool TransferModel::setData(int row, int parentRow, const QVariant &value, const QByteArray &role) {
-    return this->setData(this->index(row, 0, parentRow >= 0 ? this->index(parentRow, 0)
-                                                            : QModelIndex()), value, this->roleNames().key(role));
+bool TransferModel::setData(const QModelIndex &index, const QVariant &value, const QByteArray &role) {
+    return this->setData(index, value, this->roleNames().key(role));
 }
 
 bool TransferModel::setData(const QString &id, const QVariant &value, const QByteArray &role) {
@@ -483,10 +481,6 @@ Transfer* TransferModel::get(const QModelIndex &index) const {
     return index.isValid() ? static_cast<Transfer*>(index.internalPointer()) : m_rootItem;
 }
 
-Transfer* TransferModel::get(int row, int parentRow) const {
-    return this->get(this->index(row, 0, parentRow >= 0 ? this->index(parentRow, 0) : QModelIndex()));
-}
-
 Transfer* TransferModel::get(const QString &id) const {
     foreach (Transfer *transfer, m_rootItem->childTransfers()) {
         if (transfer->id() == id) {
@@ -524,15 +518,6 @@ void TransferModel::move(const QModelIndex &sourceParent, int sourceRow,
     }
 }
 
-void TransferModel::move(int sourceParentRow, int sourceRow, int destinationParentRow, int destinationRow) {
-    const QModelIndex sourceParent = (sourceParentRow == -1 ? QModelIndex()
-                                                            : this->index(sourceParentRow, 0, QModelIndex()));
-    const QModelIndex destinationParent = (destinationParentRow == -1 ? QModelIndex()
-                                                                      : this->index(destinationParentRow, 0, QModelIndex()));
-    
-    this->move(sourceParent, sourceRow, destinationParent, destinationRow);
-}
-
 QModelIndexList TransferModel::match(const QModelIndex &start, int role, const QVariant &value,
                                      int hits, Qt::MatchFlags flags) const {
                                      
@@ -628,11 +613,10 @@ void TransferModel::addTransfer(const QUrl &url, const QString &service, const Q
 #endif
     this->connect(transfer, SIGNAL(statusChanged(Transfers::Status)), this, SLOT(onTransferStatusChanged(Transfers::Status)));
 
-    if ((Settings::instance()->startTransfersAutomatically()) && (m_activeTransfers.size() < Settings::instance()->maximumConcurrentTransfers())) {
-        if (this->canAddActiveTransfer(transfer)) {
-            this->addActiveTransfer(transfer);
-            transfer->start();
-        }
+    if ((Settings::instance()->startTransfersAutomatically())
+        && (m_activeTransfers.size() < Settings::instance()->maximumConcurrentTransfers())) {
+        this->addActiveTransfer(transfer);
+        transfer->start();
     }
 }
 
@@ -643,9 +627,7 @@ void TransferModel::getNextTransfers() {
         foreach (Transfer *parentTransfer, m_rootItem->childTransfers()) {
             if ((parentTransfer->priority() == priority) && (parentTransfer->status() == Transfers::Queued)) {
                 if (m_activeTransfers.size() < Settings::instance()->maximumConcurrentTransfers()) {
-                    if (this->canAddActiveTransfer(parentTransfer)) {
-                        this->addActiveTransfer(parentTransfer);
-                    }
+                    this->addActiveTransfer(parentTransfer);
                 }
                 else {
                     return;
@@ -655,9 +637,7 @@ void TransferModel::getNextTransfers() {
             foreach (Transfer *transfer, parentTransfer->childTransfers()) {
                 if ((transfer->priority() == priority) && (transfer->status() == Transfers::Queued)) {
                     if (m_activeTransfers.size() < Settings::instance()->maximumConcurrentTransfers()) {
-                        if (this->canAddActiveTransfer(transfer)) {
-                            this->addActiveTransfer(transfer);
-                        }
+                        this->addActiveTransfer(parentTransfer);
                     }
                     else {
                         return;
@@ -678,26 +658,6 @@ void TransferModel::startNextTransfers() {
     }
 }
 
-bool TransferModel::canAddActiveTransfer(Transfer *transfer) {
-    if (ServicePlugin *plugin = PluginManager::instance()->getServicePlugin(transfer->serviceName())) {
-        if (plugin->maximumConnections() > 0) {
-            int count = 0;
-            
-            foreach (Transfer *t, m_activeTransfers) {
-                if (t->serviceName() == transfer->serviceName()) {
-                    count++;
-                }
-            }
-            
-            if (count >= plugin->maximumConnections()) {
-                return false;
-            }
-        }
-    }
-    
-    return true;
-}
-
 void TransferModel::addActiveTransfer(Transfer *transfer) {
     m_activeTransfers.append(transfer);
     emit activeTransfersChanged(this->activeTransfers());
@@ -867,10 +827,11 @@ void TransferModel::onTransferStatusChanged(Transfers::Status status) {
 
             break;
         }
-
+        
+        QMetaObject::invokeMethod(this, "storeTransfers", Qt::QueuedConnection);
         break;
     }
-    case Transfers::Cancelled:
+    case Transfers::Canceled:
     case Transfers::Completed:
     {
         if (Transfer *transfer = qobject_cast<Transfer*>(this->sender())) {
@@ -933,6 +894,8 @@ void TransferModel::onTransferStatusChanged(Transfers::Status status) {
 
             QMetaObject::invokeMethod(this, "storeTransfers", Qt::QueuedConnection);
         }
+        
+        break;
     }
     default:
         break;
